macro_rules! map_vec {
($thing:expr, $mapfn:expr) => { ... };
}Expand description
Eliminates some of the verbosity in having iter and collect around every map call.
macro_rules! map_vec {
($thing:expr, $mapfn:expr) => { ... };
}Eliminates some of the verbosity in having iter and collect around every map call.